@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw( $VERSION $AUTOLOAD );
-$VERSION = '1.06';
+$VERSION = '1.08';
 
 use Scalar::Util qw( blessed refaddr reftype weaken );
 use UNIVERSAL::isa;
@@ -92,7 +92,6 @@ sub set_bound
 		SCALAR => sub { $$ref },
 		ARRAY  => sub { @$ref },
 		HASH   => sub { %$ref },
-
 	);
 
 	return unless exists $bindings{reftype( $ref )};
@@ -142,7 +141,8 @@ sub called
 {
 	my ($self, $sub) = @_;
 
-	for my $called (reverse @{ _calls( $self ) }) {
+	for my $called (reverse @{ _calls( $self ) })
+	{
 		return 1 if $called->[0] eq $sub;
 	}
 
@@ -285,13 +285,22 @@ sub called_args_pos_is
 sub fake_module
 {
 	my ($class, $modname, %subs) = @_;
+
+	if ($class->check_class_loaded( $modname ) and ! keys %subs)
+	{
+		require Carp;
+		Carp::croak( "No mocked subs for loaded module '$modname'" );
+	}
+
 	$modname =~ s!::!/!g;
 	$INC{ $modname . '.pm' } = 1;
 
 	my $warn = $SIG{__WARN__};
 	local $SIG{__WARN__} = sub { $warn->( $_[0] ) unless $_[0] =~ /redefined/ };
-	no strict 'refs';
-	${ $modname . '::' }{VERSION} ||= -1;
+	{
+		no strict 'refs';
+		${ $modname . '::' }{VERSION} ||= -1;
+	}
 
 	for my $sub (keys %subs)
 	{
@@ -302,10 +311,35 @@ sub fake_module
 			Carp::carp("'$sub' is not a code reference" );
 			next;
 		}
+		no strict 'refs';
 		*{ $_[1] . '::' . $sub } = $subs{ $sub };
 	}
 }
 
+sub check_class_loaded
+{
+	my ($self, $class, $load_flag) = @_;
+
+	(my $path    = $class) =~ s{::}{/}g;
+	return 1 if exists $INC{ $path . '.pm' };
+
+	my $symtable = \%main::;
+	my $found    = 1;
+
+	for my $symbol ( split( '::', $class ))
+	{
+		unless (exists $symtable->{ $symbol . '::' })
+		{
+			$found = 0;
+			last;
+		}
+
+		$symtable = $symtable->{ $symbol . '::' };
+	}
+
+	return $found;
+}
+
 sub fake_new
 {
 	my ($self, $class) = @_;
@@ -538,6 +572,12 @@ C<import()>:
 	is( $import, 'Regexp::Esperanto',
 		'Regexp::Esperanto should use() Regexp::English' );
 
+If you use C<fake_module()> to mock a module that already exists in memory --
+one you've loaded elsewhere perhaps, but do not pass any subroutines to mock,
+this method will throw an exception.  This is because if you call the
+constructor later on, you probably won't get a mock object back and you'll be
+confused.
+
 =item * C<fake_new(I<module name>)>
 
 B<Note:> see L<Test::MockObject::Extends> for a better alternative to this
@@ -753,6 +793,11 @@ Joins together all of the arguments to a method at the appropriate position and
 matches against a specified string.  A generically bland test name is provided
 by default.  You can probably do much better.
 
+=item * C<check_class_loaded( $class_name )>
+
+Attempts to determine whether you have a class of the given name loaded and
+compiled.  Returns true or false.
+
 =back
 
 =head3 Logging
@@ -769,7 +814,7 @@ will set mock both C<foo()> and C<bar()>, causing both to return true.
 However, the object will log only calls to C<bar()>, not C<foo()>.  To log
 C<foo()> again, merely mock it again without the leading C<->:
 
-	$mock->set_true( '-foo' );
+	$mock->set_true( 'foo' );
 
 C<$mock> will log all subsequent calls to C<foo()> again.
 
@@ -816,6 +861,10 @@ Test::MockObject::Extends.
 
 Stevan Little provided the impetus and code for C<set_isa()>.
 
+Nicholas Clark found a documentation error.
+
+Mutant suggested a potential problem with fake_module().
+
 =head1 SEE ALSO
 
 L<perl>, L<Test::Tutorial>, L<Test::More>,
@@ -825,7 +874,7 @@ L<http:E<sol>E<sol>www.perl.comE<sol>pubE<sol>aE<sol>2002E<sol>07E<sol>10E<sol>t
 
 =head1 COPYRIGHT
 
-Copyright 2002 - 2005 by chromatic E<lt>chromatic at wgz dot orgE<gt>.
+Copyright (c) 2002 - 2006 by chromatic E<lt>chromatic at wgz dot orgE<gt>.
 
 This program is free software; you can use, modify, and redistribute it under
 the same terms as Perl 5.8.x itself.
