@@ -9,7 +9,7 @@ use Devel::Peek  'CvGV';
 use Scalar::Util 'blessed';
 
 use vars qw( $VERSION $AUTOLOAD );
-$VERSION = '1.05';
+$VERSION = '1.08';
 
 sub new
 {
@@ -27,26 +27,13 @@ sub new
 sub check_class_loaded
 {
 	my ($self, $parent_class) = @_;
+	my $result                = Test::MockObject->check_class_loaded(
+		$parent_class
+	);
+	return $result if $result;
 
-	my $symtable = \%main::;
-	my $found    = 1;
-
-	for my $symbol ( split( '::', $parent_class ))
-	{
-		unless (exists $symtable->{ $symbol . '::' })
-		{
-			$found = 0;
-			last;
-		}
-
-		$symbol = $symtable->{ $symbol . '::' };
-	}
-
-	unless ($found)
-	{
-		(my $load_class  = $parent_class) =~ s/::/\//g;
-		require $load_class . '.pm';
-	}
+	(my $load_class  = $parent_class) =~ s/::/\//g;
+	require $load_class . '.pm';
 }
 
 sub get_class
@@ -65,16 +52,27 @@ sub gen_package
 	my $package                  = 'T::MO::E::' . $packname++;
 
 	no strict 'refs';
-	*{ $package . '::mock'     } = \&mock;
-	*{ $package . '::unmock'   } = \&unmock;
-	*{ $package . '::ISA'      } = [ $parent ];
-	*{ $package . '::can'      } = $class->gen_can( $parent );
-	*{ $package . '::isa'      } = $class->gen_isa( $parent );
-	*{ $package . '::AUTOLOAD' } = $class->gen_autoload( $parent );
+	*{ $package . '::mock'          } = \&mock;
+	*{ $package . '::unmock'        } = \&unmock;
+	@{ $package . '::ISA'           } = ( $parent );
+	*{ $package . '::can'           } = $class->gen_can( $parent );
+	*{ $package . '::isa'           } = $class->gen_isa( $parent );
+	*{ $package . '::AUTOLOAD'      } = $class->gen_autoload( $parent );
+	*{ $package . '::__get_parents' } = $class->gen_get_parents( $parent );
 
 	return $package;
 }
 
+sub gen_get_parents
+{
+	my ($self, $parent) = @_;
+	return sub
+	{
+		no strict 'refs';
+		return @{ $parent . '::ISA' };
+	};
+}
+
 sub gen_isa
 {
 	my ($class, $parent)    = @_;
@@ -132,6 +130,10 @@ sub gen_autoload
 			unshift @_, $self;
 			goto &$parent_al;
 		}
+		else
+		{
+			die "Undefined method $method at ", join( ' ', caller() ), "\n";
+		}
 	};
 }
 
@@ -221,6 +223,9 @@ This may fail, so beware.
 If you pass no arguments, it will assume you really meant to create a normal
 C<Test::MockObject> object and will oblige you.
 
+Note that if you pass a class, the object returned will appear to be an
+instance of that class; I<this does not mock the class itself>.
+
 =item C<mock( $methodname, $sub_ref )>
 
 See the documentation for Test::MockObject for all of the ways to mock methods
@@ -269,6 +274,11 @@ order as C<gen_autoload()>.
 Returns an C<isa()> method for the mock object that claims to be the
 C<$extended> object appropriately.
 
+=item * C<gen_get_parents( $extended )>
+
+Returns a C<__get_parents()> method for the mock object that claims to be the
+C<$extended> object appropriately.
+
 =item * C<gen_package( $extended )>
 
 Creates a new unique package for the mock object with the appropriate methods
@@ -294,7 +304,8 @@ C<Test::MockObject>, though this should be rare.
 chromatic, E<lt>chromatic at wgz dot orgE<gt>
 
 Documentation bug fixed by Stevan Little.  Additional AUTOLOAD approach
-suggested by Adam Kennedy.
+suggested by Adam Kennedy.  Other bugs reported by Paul the Nomad and Praveen
+Ray.  Thank you all!
 
 =head1 BUGS
 
